API
===

.. toctree::
   :maxdepth: 2

   mplsoccer.pitch
   mplsoccer.radar_chart
   mplsoccer.statsbomb
   mplsoccer.bumpy_chart
   mplsoccer.py_pizza
   mplsoccer.utils
   mplsoccer.quiver
   mplsoccer.linecollection
   mplsoccer.grid
